#ifndef PanelGLH //To avoid linker errors, define header's unique "name", so...
#define PanelGLH //...this header will not be compilled more than one time
//==============================================================================
#include <gl\gl.h>      // Header file for the main OpenGL library
#include <gl\glu.h>     // Header file for the GLu library
//------------------------------------------------------------------------------
#include <wingdi.h>     // System header file
//------------------------------------------------------------------------------
#include <ExtCtrls.hpp> //Header containing definition of TPanel class
#include <Controls.hpp> //Header containing auxilary necessary definitions
#include <Graphics.hpp> //Header containing auxilary necessary definitions
//==============================================================================

//Function prepares given panel (class TPanel) to be a canvas for 3D
void pglPreparePanel(TPanel *PanelFor3D)
 {
  //Avoid panel to have any borders
  PanelFor3D->BevelInner = bvNone;
  PanelFor3D->BevelOuter = bvNone;
  PanelFor3D->BevelWidth = 1;
  PanelFor3D->BorderWidth = 0;
  PanelFor3D->BorderStyle = bsNone;
  //It's not necessary to repaint borders, because this panel doesn't have them
  PanelFor3D->FullRepaint = false;
  //Remove any text from panel
  PanelFor3D->Caption = "";
  //Disable any pop-up hints on graphic area
  PanelFor3D->ShowHint = false;
  PanelFor3D->ParentShowHint = false;
  //Configure range of panel's size
  PanelFor3D->Constraints->MaxHeight=0;//There is no limit for maximum height
  PanelFor3D->Constraints->MaxWidth=0; //There is no limit for maximum width
  PanelFor3D->Constraints->MinHeight=1;//Do not allow Height=0 - will cause GL errors
  PanelFor3D->Constraints->MinWidth=0; //There is no limit for maximum width
  //Do not allow tab-jumping for this control
  PanelFor3D->TabStop = false;
  //Make control paint itself directly to the screen (double-buffering for GL)
  PanelFor3D->DoubleBuffered = false;
  //Set panel's color to black to indicate that preparations completed
  PanelFor3D->Color = clBlack;
 }

//Function initializes OpenGL in given panel
void pglInitOpenGL(TPanel *PanelFor3D)
 {
  //Mark our preferences concerning pixel format
  PIXELFORMATDESCRIPTOR *ppfd = new PIXELFORMATDESCRIPTOR;
  ppfd->nSize = sizeof(PIXELFORMATDESCRIPTOR);
  ppfd->nVersion = 1;
  ppfd->dwFlags = PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL;
  ppfd->dwLayerMask = PFD_MAIN_PLANE;
  ppfd->iPixelType = PFD_TYPE_RGBA;
  ppfd->cColorBits = 32;  //32 bit pixel color
  ppfd->cDepthBits = 32;  //32 bit pixel depth
  ppfd->cAccumBits = 0;   //No buffer-accumulator (?)
  ppfd->cStencilBits = 0; //No stencil buffer (?)
  //Get device context
  HDC ghDC = GetDC(PanelFor3D->Handle);
  //Setup pixel format for GL panel which is closest to choosen
  SetPixelFormat(ghDC, ChoosePixelFormat(ghDC, ppfd), ppfd);
  //Initialize OpenGL context
  HGLRC ghRC = wglCreateContext(ghDC); //Create OpenGL context
  wglMakeCurrent(ghDC, ghRC); //Make this context current for OpenGL functions
 }

//==============================================================================
#endif //End header
